import localizationConfigurer from './configurers/localization-configurer'
import api from './utils/http-client'
import { setConfig, gazelConfig } from './utils/config'
import { registerPlugins } from './plugins'
import routes from './utils/route-builder'

class Application {}

export const appStart = (Vue, options = {}) => {
    Application.vue(Vue);
    Application.constants();
    Application.config(options);
    Application.route();
    Application.import();
    Application.store();
    Application.plugins();
    Application.httpClient(Vue);
    Application.localization();
}

Application.vue = function(Vue){
    window.Vue = Vue;
}

Application.constants = function(){
    require('./constants')
}

Application.plugins = function(){
    registerPlugins();
}

Application.import = function(){
    require('./assets/gazel.scss')
}

Application.store = function(){
    require('./store')
}

Application.config = function(options){
    setConfig(options);
    Vue.prototype.$gazelConfig = gazelConfig;
    window.$gazelConfig = Vue.prototype.$gazelConfig;
}

Application.httpClient = function (Vue) {
    Vue.prototype.$api = api.getInstance();
    window.$api = Vue.prototype.$api;
}

Application.localization = function () {
    localizationConfigurer.init();
}

Application.route = function(){
    if(window.$gazelConfig.router){
        routes(window.$gazelConfig.router.context()).forEach((routeItem) => {
            let route = {};
            routeItem.components.forEach((c)=>{
                route['component'] = () => window.$gazelConfig.router.import(c.filePath); //((import(`./views/${c.filePath}`);
                route['path'] = `/${routeItem.rootUrlPath}/${c.urlPath}`;
            })
            window.$router.addRoutes([route]);
         });
    }
}