import moment from "moment";

export default {
    props: {
        options: {
            type: Object,
            required: false
        }
    },
    computed: {
        _timePicker24Hour() {
            return moment()
                .locale(this._locale)
                .localeData()
                ._longDateFormat["LT"].substring(0, 1) === "H" ?
                true :
                false;
        },
        _locale() {
            return window.$i18n.locale;
        },
        _defaultOptions() {
            return {
                timePicker: this.timePicker,
                singleDatePicker: this.singleDatePicker,
                showDropdowns: true,
                autoUpdateInput: false,
                autoApply: false,
                timePicker24Hour: this._timePicker24Hour,
                applyClass: "btn-primary",
                locale: {
                    format: this._displayFormat,
                    applyLabel: this._applyLabel,
                    cancelLabel: this._cancelLabel,
                    daysOfWeek: this._daysOfWeek,
                    monthNames: this._monthNames,
                    customRangeLabel: this._customRangeLabel,
                    firstDay: 1
                }
            };
        },
        _options() {
            let opts = {};
            Object.assign(opts, this._defaultOptions, this.options);
            return opts;
        },
        inputClasses() {
            if (this.state === null) {
                return "form-control";
            }

            return this.state ? "form-control is-valid" : "form-control is-invalid";
        },
        _monthNames() {
            return [
                window.$i18n.t("Web.Framework.DatePicker.January"),
                window.$i18n.t("Web.Framework.DatePicker.February"),
                window.$i18n.t("Web.Framework.DatePicker.March"),
                window.$i18n.t("Web.Framework.DatePicker.April"),
                window.$i18n.t("Web.Framework.DatePicker.May"),
                window.$i18n.t("Web.Framework.DatePicker.June"),
                window.$i18n.t("Web.Framework.DatePicker.July"),
                window.$i18n.t("Web.Framework.DatePicker.August"),
                window.$i18n.t("Web.Framework.DatePicker.September"),
                window.$i18n.t("Web.Framework.DatePicker.October"),
                window.$i18n.t("Web.Framework.DatePicker.November"),
                window.$i18n.t("Web.Framework.DatePicker.December")
            ];
        },
        _daysOfWeek() {
            return [
                window.$i18n.t("Web.Framework.DatePicker.SundayShortName"),
                window.$i18n.t("Web.Framework.DatePicker.MondayShortName"),
                window.$i18n.t("Web.Framework.DatePicker.TuesdayShortName"),
                window.$i18n.t("Web.Framework.DatePicker.WednesdayShortName"),
                window.$i18n.t("Web.Framework.DatePicker.ThursdayShortName"),
                window.$i18n.t("Web.Framework.DatePicker.FridayShortName"),
                window.$i18n.t("Web.Framework.DatePicker.SaturdayShortName")
            ];
        },  
        _applyLabel() {
            return window.$i18n.t("Web.Framework.DatePicker.Apply");
        },
        _cancelLabel() {
            return window.$i18n.t("Web.Framework.DatePicker.Cancel");
        },
        _customRangeLabel() {
            return window.$i18n.t("Web.Framework.CustomRange");
        }
    },
}