import {
    gazelConfig
} from './../utils/config.js'
export default {
    props: {
        value: {
            type: String | Object,
            required: true,
            default: ''
        },
        placeholder: {
            type: String,
            required: false,
            default: function () {
                return window.$i18n.t(`${this.getLocalizationKeyPrefix}.Placeholder`)
            }
        },
        label: {
            type: String,
            required: false,
            default: function () {
                return window.$i18n.t(`${this.getLocalizationKeyPrefix}.Label`)
            }
        },
        description: {
            type: String,
            required: false,
            default: function () {
                return ''
            }
        },
        labelCols: {
            type: Number,
            required: false,
            default: 0
        },
        name: {
            type: String,
            required: false,
            default: function () {
                var result, i, j;
                result = '';
                for (j = 0; j < 32; j++) {
                    if (j == 8 || j == 12 || j == 16 || j == 20)
                        result = result + '-';
                    i = Math.floor(Math.random() * 16).toString(16).toUpperCase();
                    result = result + i;
                }
                return result;
            }
        },
        validate: {
            type: String,
            required: false,
            default: function () {
                return null;
            }
        },
        minlength: {
            type: Number | Object,
            required: false,
            default: function () {
                return null;
            }
        },
        maxlength: {
            type: Number | Object,
            required: false,
            default: function () {
                return null;
            }
        },
        pattern: {
            type: String,
            required: false,
            default: function () {
                return null;
            }
        },
        showValidStyle: {
            type: Boolean | Object,
            required: false,
            default: null
        },
        showInvalidStyle: {
            type: Boolean | Object,
            required: false,
            default: null
        },
        showInvalidIcon: {
            type: Boolean | Object,
            required: false,
            default: null
        },
        showValidIcon: {
            type: Boolean | Object,
            required: false,
            default: null
        },
        requiredMessage: {
            type: String,
            required: false,
            default: null
        },
        validMessage: {
            type: String,
            required: false,
            default: null
        },
        invalidMessage: {
            type: String,
            required: false,
            default: null
        },
        showValidMessage: {
            type: Boolean,
            required: false,
            default: null
        },
        showInvalidMessage: {
            type: Boolean,
            required: false,
            default: null,
        },
        showRequiredMessage: {
            type: Boolean,
            required: false,
            default: null
        },
        minlengthMessage: {
            type: String,
            required: false,
            default: null
        },
        maxlengthMessage: {
            type: String,
            required: false,
            default: null
        },
        patternMessage: {
            type: String,
            required: false,
            default: null
        }
    },
    data() {
        return {
            errors: [],
            inputVal: this.value === null ? '' : this.value.toString(),
            validateControl: null,
            fieldMessageControl: null,
            control: this,
        }
    },
    computed: {
        _showValidStyle() {
            if (this.showValidStyle != null) {
                return this.showValidStyle;
            }
            if (this.formValidation.show.validStyle != null) {
                return this.formValidation.show.validStyle;
            }
            if (gazelConfig.form.validation.show.validStyle != null) {
                return gazelConfig.form.validation.show.validStyle;
            }
            return true;
        },
        _showInvalidStyle() {
            if (this.showInvalidStyle != null) {
                return this.showInvalidStyle;
            }
            if (this.formValidation.show.invalidStyle != null) {
                return this.formValidation.show.invalidStyle;
            }
            if (gazelConfig.form.validation.show.invalidStyle != null) {
                return gazelConfig.form.validation.show.invalidStyle;
            }
            return true;
        },
        _showInvalidIcon() {
            if (this.showInvalidIcon != null) {
                return this.showInvalidIcon;
            }
            if (this.formValidation.show.invalidIcon != null) {
                return this.formValidation.show.invalidIcon;
            }
            if (gazelConfig.form.validation.show.invalidIcon != null) {
                return gazelConfig.form.validation.show.invalidIcon;
            }
            return true;
        },
        _showValidIcon() {
            if (this.showValidIcon != null) {
                return this.showValidIcon;
            }
            if (this.formValidation.show.validIcon != null) {
                return this.formValidation.show.validIcon;
            }
            if (gazelConfig.form.validation.show.validIcon != null) {
                return gazelConfig.form.validation.show.validIcon;
            }
            return true;
        },
        configValidate() {
            return gazelConfig.form.validation.validate;
        },
        formValidation() {
            if(this.validateControl == null || this.validateControl.vueFormParentForm === undefined){
                return gazelConfig.form.validation;
            }
             return this.validateControl.vueFormParentForm._validation;
        },
        formValidate() {
            return this.formValidation.validate;
        },
        state() {
            this.$nextTick(() => {
                this.validateControl = this.$refs.gValidateControl;
                this.fieldMessageControl = this.$refs.gFieldMessage;
            });
            let result = null;

            if (this.validateControl != null) {
                if (this.validateControl.formstate[this.name] !== undefined) {
                    if (this.validateControl.formstate[this.name].$submitted === true) {
                        result = this.validateControl.formstate[this.name].$valid;
                    }
                    if (this.validateControl.formstate[this.name].$touched === true) {
                        if (this.validate != null) {
                            if ((this.validate === 'onTouch' || this.validate === 'onCreate')) {
                                result = this.validateControl.formstate[this.name].$valid;
                            }
                        } else if (this.formValidate != null) {
                            if ((this.formValidate === 'onTouch' || this.formValidate === 'onCreate')) {
                                result = this.validateControl.formstate[this.name].$valid;
                            }
                        } else if (this.configValidate != null) {
                            if ((this.configValidate === 'onTouch' || this.configValidate === 'onCreate')) {
                                result = this.validateControl.formstate[this.name].$valid;
                            }
                        }
                    }
                    if (this.validateControl.formstate[this.name].$untouched === true) {

                        if (this.validate != null) {
                            if (this.validate === 'onCreate') {
                                result = this.validateControl.formstate[this.name].$valid;
                            }
                        } else if (this.formValidate != null) {
                            if (this.formValidate === 'onCreate') {
                                result = this.validateControl.formstate[this.name].$valid;
                            }
                        } else if (this.configValidate != null) {

                            if (this.configValidate === 'onCreate') {
                                result = this.validateControl.formstate[this.name].$valid;
                            }
                        }
                    }
                }
            }
            return result;
        },
        getLocalizationKeyPrefix: {
            cache: false,
            get() {
                const componentName = this.$options.name.replace('G', '').replace('Form', '');
                return `Web.Framework.${componentName}`;
            }
        }
    },
    mounted() {
        this.$nextTick(() => {
            let control = null;
            let parentControl = null;
            if (this.$refs.gFormControl !== undefined) {
                if (this.$refs.gFormControl.$refs['search'] !== undefined) {
                    control = this.$refs.gFormControl.$refs['search'];
                } else if (this.$refs.gFormControl.$refs['input'] !== undefined) {
                    control = this.$refs.gFormControl.$refs['input'];
                } else {
                    control = this.$refs.gFormControl.$el;
                }

                if (this.$refs.gFormControl.$parent != null) {
                    parentControl = this.$refs.gFormControl.$parent.$refs['content'];
                }
            }
            if (control != null) {
                if (this._showValidStyle === false) {
                    control.style.setProperty('--valid-border-color', '#ced4da');
                    control.style.setProperty('--valid-box-shadow', 'none');
                }
                if (this._showInvalidStyle === false) {
                    control.style.setProperty('--invalid-border-color', '#ced4da');
                    control.style.setProperty('--invalid-box-shadow', 'none');
                }
                if (this._showInvalidIcon === true) {
                    control.style.setProperty('--invalid-background-image', `url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='%23dc3545' viewBox='-2 -2 7 7'%3E%3Cpath stroke='%23dc3545' d='M0 0l3 3m0-3L0 3'/%3E%3Ccircle r='.5'/%3E%3Ccircle cx='3' r='.5'/%3E%3Ccircle cy='3' r='.5'/%3E%3Ccircle cx='3' cy='3' r='.5'/%3E%3C/svg%3E")`);
                }
                if (this._showValidIcon === true) {
                    control.style.setProperty('--valid-background-image', `url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3E%3Cpath fill='%2328a745' d='M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/%3E%3C/svg%3E")`);
                }
            }
            if (parentControl != null) {
                if (this._showValidStyle === false) {
                    parentControl.style.setProperty('--valid-border-color', '#ced4da');
                }
                if (this._showInvalidStyle === false) {
                    parentControl.style.setProperty('--invalid-border-color', '#ced4da');
                }
                if (this._showInvalidIcon === true) {
                    parentControl.style.setProperty('--v-select-invalid-padding', `0px 30px 0px 3px`);
                    parentControl.style.setProperty('--invalid-background-image', `url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' fill='%23dc3545' viewBox='-2 -2 7 7'%3E%3Cpath stroke='%23dc3545' d='M0 0l3 3m0-3L0 3'/%3E%3Ccircle r='.5'/%3E%3Ccircle cx='3' r='.5'/%3E%3Ccircle cy='3' r='.5'/%3E%3Ccircle cx='3' cy='3' r='.5'/%3E%3C/svg%3E")`);
                }
                if (this._showValidIcon === true) {
                    parentControl.style.setProperty('--v-select-valid-padding', `0px 30px 0px 3px`);
                    parentControl.style.setProperty('--valid-background-image', `url("data:image/svg+xml;charset=utf-8,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3E%3Cpath fill='%2328a745' d='M2.3 6.73L.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/%3E%3C/svg%3E")`);
                }
            }   
        })
    },
    watch: {
        inputVal(val) {
            this.inputEmit(val);
        },
        value() {
            this.inputVal = this.value;
        }
    },
    methods: {
        isNumber(value) {
            return /^\d+$/.test(value)
        },
        inputEmit(val){
            this.$emit('input', val);
        }
    },
}