import { gazelConfig } from './../utils/config.js'
export default {
    props: {
        onValidate: {
            required: false,
            type: Function,
            default: () => true,
        }
    },
    data() {
        return {
            parentformValidation: null,
            customMessage: ''
        }
    },
    created() {
        this.$nextTick(() => {
            if (this.$refs.gFieldMessageControl != null && this.$refs.gFieldMessageControl.vueFormParentForm != null) {
                this.parentformValidation = this.$refs.gFieldMessageControl.vueFormParentForm._validation;
            }
        });
    },
    methods: {
        customValidator(value) {
            const result = this.onValidate(value);
            if (result === undefined) {
                throw 'undefined result';
            }
            if (typeof result === 'boolean') {
                return result;
            }
            this.customMessage = result.message;
            return result.success;
        }
    },
    computed: {
        _formValidation() {
            return this.parentformValidation;
        },
        _customMessage() {
            return this.customMessage;
        },
        _showValidMessage() {
            if (this.control.showValidMessage != null) {
                return this.control.showValidMessage;
            }
            if (this._formValidation != null && this._formValidation.show.validMessage != null) {
                return this._formValidation.show.validMessage;
            }
            if (gazelConfig.form.validation.show.validMessage != null) {
                return gazelConfig.form.validation.show.validMessage;
            }
            return true;
        },
        _showInvalidMessage() {
            if (this.control.showInvalidMessage != null) {
                return this.control.showInvalidMessage;
            }
            if (this._formValidation != null && this._formValidation.show.invalidMessage != null) {
                return this._formValidation.show.invalidMessage;
            }
            if (gazelConfig.form.validation.show.invalidMessage != null) {
                return gazelConfig.form.validation.show.invalidMessage;
            }
            return true;
        },
        _showRequiredMessage() {
            if (this.control.showRequiredMessage != null) {
                return this.control.showRequiredMessage;
            }
            if (this._formValidation != null && this._formValidation.show.requiredMessage != null) {
                return this._formValidation.show.requiredMessage;
            }
            if (gazelConfig.form.validation.show.requiredMessage != null) {
                return gazelConfig.form.validation.show.requiredMessage;
            }
            return true;
        },

        _validMessage() {
            if (this.control.validMessage != null) {
                return this.control.validMessage;
            }
            if (this._formValidation != null && this._formValidation.message.valid() != null) {
                return this._formValidation.message.valid();
            }
            if (gazelConfig.form.validation.message.valid() != null) {
                return gazelConfig.form.validation.message.valid();
            }
            return '';
        },

        _invalidMessage() {
            if (this.control.invalidMessage != null) {
                return this.control.invalidMessage;
            }
            if (this._formValidation != null && this._formValidation.message.invalid() != null) {
                return this._formValidation.message.invalid();
            }
            if (gazelConfig.form.validation.message.invalid() != null) {
                return gazelConfig.form.validation.message.invalid();
            }
            return '';
        },

        _requiredMessage() {
            if (this.control.requiredMessage != null) {
                return this.control.requiredMessage;
            }
            if (this._formValidation != null && this._formValidation.message.required() != null) {
                return this._formValidation.message.required();
            }
            if (gazelConfig.form.validation.message.required() != null) {
                return gazelConfig.form.validation.message.required();
            }
            return '';
        },

        _minlengthMessage() {

            if (this.control.minlengthMessage != null) {
                return this.control.minlengthMessage;
            }
            if (this._formValidation != null && this._formValidation.message.minlength() != null) {
                return this._formValidation.message.minlength();
            }
            if (gazelConfig.form.validation.message.minlength() != null) {
                return gazelConfig.form.validation.message.minlength().format(this.control.minlength);
            }

            return '';
        },

        _maxlengthMessage() {

            if (this.control.maxlengthMessage != null) {
                return this.control.maxlengthMessage;
            }
            if (this._formValidation != null && this._formValidation.message.maxlength() != null) {
                return this._formValidation.message.maxlength();
            }
            if (gazelConfig.form.validation.message.maxlength() != null) {
                return gazelConfig.form.validation.message.maxlength().format(this.control.maxlength);
            }

            return '';
        },

        _patternMessage() {
            if (this.control.patternMessage != null) {
                return this.control.patternMessage;
            }
            if (this._formValidation != null && this._formValidation.message.pattern() != null) {
                return this._formValidation.message.pattern();
            }
            if (gazelConfig.form.validation.message.pattern() != null) {
                return gazelConfig.form.validation.message.pattern().format(this.control.pattern);
            }

            return '';
        }
    },
}