export const strict = false
import 'es6-promise/auto'
import Vuex from 'vuex'
import localizationTextModule from './modules/localization-text/index'
import languageModule from './modules/language'

Vue.use(Vuex)

const debug = process.env.NODE_ENV !== 'production'

const store = new Vuex.Store({
  modules: {
    localizationTextModule,
    languageModule
  },
  strict: debug
})

Vue.prototype.$store = store;
store.$context = Vue.prototype.$context;

store.subscribeAction({
  after: (action) => {
    switch (action.type) {
      case 'localizationTextModule/setLocalizationText':
        Vue.prototype.$localStorage.set($gazelConstants.Store.LOCALIZATION_TEXT, JSON.stringify(store.state.localizationTextModule));
        break;
      case 'languageModule/initialise':
        Vue.prototype.$localStorage.set(window.$gazelConstants.Store.LANGUAGE, JSON.stringify(store.state.languageModule));
        break;
      case 'languageModule/setLanguages':
        Vue.prototype.$store.dispatch('localizationTextModule/initialise')
        break;
      case 'languageModule/setCurrentLanguage':
        Vue.prototype.$localStorage.set(window.$gazelConstants.Store.LANGUAGE, JSON.stringify(store.state.languageModule));

        const languageCode = store.state.languageModule.currentLanguage.languageCode.toLowerCase();
        window.$i18n.locale = languageCode;
        window.$i18n.cultureCode = store.state.languageModule.currentLanguage.specificCultureName;
        window.$api.defaults.headers.common['X-Language-Code'] = store.state.languageModule.currentLanguage.specificCultureName;
        document.querySelector('html').setAttribute('lang', window.$i18n.locale)

        Vue.prototype.$store.dispatch('localizationTextModule/setLocalizationText', store.state.languageModule.currentLanguage)

        break;
    }
  }
})

export default store;