const defaultConfig = {
  httpHeaders: {
    'Accept': 'application/json',
    'Content-Type': 'application/json;charset=UTF-8'
  },
  service: {
    urlBase: '',
    appToken: ''
  },
  apps:{
      list:async function () {
        return [];
    },
  },
  localization: {
    texts: async function (languageCode) {
        return [];
    },
    languages: async function () {
        return [];
    },
    default:'en-US'
  },
  form: {
    validation: {
      validate: 'onSubmit',
      show: {
        validMessage: false,
        invalidMessage: true,
        requiredMessage: true,
        validStyle: false,
        invalidStyle: true,
        validIcon: false,
        invalidIcon: false,
      },
      message: {
        required: () => 'This field is required.',
        pattern: () => 'Pattern does not match, format example: {0}.',
        minlength: () => 'Please enter at least {0} characters.',
        maxlength: () => 'Please enter no more than {0} characters.',
        min: () => 'Please enter a value greater than or equal to {0}.',
        max: () => 'Please enter a value less than or equal to {0}.',
        valid:()=> 'Valid message',
        invalid:()=>'Invalid message'
      }
    },
    enum: {
      translate: {
        enabled: true,
        prefix: 'Web.Enum',
      },
      noOption:()=>'Please select'
    }
  }
}

export let gazelConfig = Object.assign({}, defaultConfig);

export const setConfig = function (cfg) {
  gazelConfig = mergeDeep(gazelConfig, cfg);
}

function isObject(item) {
  return (item && typeof item === 'object' && !Array.isArray(item));
}

export function mergeDeep(target, ...sources) {
  if (!sources.length) return target;
  const source = sources.shift();

  if (isObject(target) && isObject(source)) {
    for (const key in source) {
      if (isObject(source[key])) {
        if (!target[key]) Object.assign(target, {
          [key]: {}
        });
        mergeDeep(target[key], source[key]);
      } else {
        Object.assign(target, {
          [key]: source[key]
        });
      }
    }
  }
  return mergeDeep(target, ...sources);
}

export function convertVueFormValidate(validate) {
  let result = '';
  if (validate === 'onSubmit') {
    result = '$submitted || ';
  }
  if (validate === 'onTouch') {
    result += '$touched || $submitted || ';
  }
  if (validate === 'onCreate') {
    result += '$untouched || $touched || ';
  }
  if (result.length > 0) {
    result = result.split("").reverse().join("").replace(' || ', '').split("").reverse().join("");
  }
  return result;
}


export function convertGazelFormValidate(validate) {

  if (validate === '$submitted') {
    return 'onSubmit';
  }

  if (validate === '$touched') {
    return 'onTouch';
  }

  if (validate === '$untouched') {
    return 'onCreate';
  }

  return '';

}