import { gazelConfig, mergeDeep } from './config'
import axios from 'axios';

export default class HttpClient {

        constructor() {
                this.axios = axios.create({ baseURL: gazelConfig.service.urlBase });
                this.axios.defaults.headers.common['Authorization'] = gazelConfig.service.appToken;
                mergeDeep(this.axios.defaults, { headers: gazelConfig.httpHeaders })
        }

        static getInstance() {
                return new HttpClient();
        }

        get interceptors() {
                return this.axios.interceptors;
        }

        get defaults() {
                return this.axios.defaults;
        }

        get(path, headers) {
                return new Promise((resolve, reject) => {
                        this.axios
                                .get(path, { headers: mergeDeep(gazelConfig.httpHeaders, headers) })
                                .then(response => { resolve(response) })
                                .catch(error => { reject(error) });
                });
        }

        post(path, data, headers) {
                return new Promise((resolve, reject) => {
                        this.axios
                                .post(path, data, { headers: mergeDeep(gazelConfig.httpHeaders, headers) })
                                .then(response => { resolve(response) })
                                .catch(error => { reject(error) });
                });
        }

        patch(path, data, headers) {
                return new Promise((resolve, reject) => {
                        this.axios
                                .patch(path, data, { headers: mergeDeep(gazelConfig.httpHeaders, headers) })
                                .then(response => { resolve(response) })
                                .catch(error => { reject(error) });
                });
        }

        del(path) {
                return new Promise((resolve, reject) => {
                        this.axios
                                .delete(path, { headers: mergeDeep(gazelConfig.httpHeaders, headers) })
                                .then(response => { resolve(response) })
                                .catch(error => { reject(error) });
                });
        }
}