import upperFirst from 'lodash/upperFirst'
import camelCase from 'lodash/camelCase'
import startsWith from 'lodash/startsWith'


class ViewComponent {

    constructor(rootPath) {
        this.rootUrlPath = rootPath;
        this.components = [];
    }

    builder(filePath) {
        const componentName = filePath.split('/').pop();
        if (!this.components.some(c => c.name == componentName)) {

            if (startsWith(filePath, './')) {
                filePath = filePath.replace('./', '')
            }

            let urlPath = componentName.replace('.vue', '');

            let urlParameters = urlPath.split('@');

            let urlParams = []
            if(urlParameters && urlParameters.length>1){
                urlParams = urlParameters.slice(1);
            }

            if(urlPath.toLowerCase() === 'index'){
                urlPath = '';
            }
            else if(urlParams && urlParams.length>0){
                let urlBuilder = '';
                urlParams.forEach(item=>{
                    urlBuilder+=`/:${item}`
                });
                if(urlBuilder[0] === '/'){
                    urlBuilder = urlBuilder.slice(1);
                }
                urlPath = `${urlBuilder}/${urlParameters[0]}`;
            }

            this.components.push({
                'name': upperFirst(camelCase(componentName.replace(/\.\w+$/, ''))),
                'filePath': filePath,
                'urlPath': urlPath
            });
        }
    }
}


function getRoutes(context) {
    const requireComponent = context;

    let viewComponents = [];

    requireComponent.keys().forEach(fileName => {

        const rootPath = fileName.split('/').slice(1, -1).join('/');

        let viewComponent = viewComponents.find(vc => vc.rootPath == rootPath);

        if (!viewComponent || viewComponent === undefined) {
            viewComponent = new ViewComponent(rootPath);
            viewComponents.push(viewComponent);
        }

        viewComponent.builder(fileName)
    })

    return viewComponents;
}

export default getRoutes